@@ -7,6 +7,31 @@ import numpy as np
 from scipy.stats import norm, mstats
 warnings.filterwarnings("ignore")
 
+
+'''
+=====目录区=====
+1. 计算七麦外的其他备用工具；
+2. 计算七麦内的备用工具；
+3. 常用的自定义参数；
+4. 获取基础信息相关数据；
+5. 获取榜单相关数据；
+6. 获取开发商相关数据；
+7. 获取关键词的相关数据；
+8. 获取产品的关键词相关数据；
+9. 获取产品评论的相关接口；
+10. 获取清榜列表相关数据；
+11. 获取清词列表相关数据；
+12. 获取下架产品列表相关数据；
+13. 获取预订App列表；
+14. 获取产品被精品推荐及上热搜情况列表；
+15. 获取App不同状态列表；
+16. 封装指数排行榜接口；
+17. 封装关键词落词列表接口；
+18. 获取免费、付费、畅销榜单产品列表；
+
+'''
+
+
 # 保持会话；
 session = requests.session()
 
@@ -88,6 +113,19 @@ class Qimai_Outside_Tool:
     def __init__(self, *args):
         self.data_info = args
 
+    def match_str_chinese(self):
+        for ch in self.data_info[0]:
+            if u'\u4e00' <= ch <= u'\u9fff':
+                return True
+        return False
+
+    def match_publisher_company(self):
+        company_str_list = ['公司', 'Technology', 'Beijing', '(', ')', '（', '）', 'Ltd', '.', 'Inc', 'china', '互联网', '科技', '网络', '计算机', 'LLC', '-', 'Company', 'games', '工作室', 'Tech', '信息', 'online', 'Network', '互动', '移动', '游戏', '技术', 'LIMITED', '株式会社', 'Tov', 'USA', 'UK', '银行', '组织', '机构']
+        for company_str in company_str_list:
+            if company_str.lower() in self.data_info[0].lower() or len(self.data_info[0])>20:
+                return True
+        return False
+
     def json_to_df(self):
         self.json_df = json_normalize(self.data_info[0])
         return self.json_df
@@ -205,7 +243,7 @@ class Qimai_Intside_Tool:
 
 # 常用的自定义参数；
 class Qimai_Diy_Var:
-    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', search_type='all', brand='all', day=1, appRankShow=1, subclass='all', simple=1, rankEchartType=1, rankType='day', run_time=datetime.date.today(), status=6, keyword_hot_start=4605, typec='day', star='five', delete=-1, orderType='time', commentType='default', genre_type=36, status_type=3, clear_type=1, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc', option=4, app_status_str='all', app_status_sdate='', app_status_edate='', app_status_order='', app_status_sort='', preOrder_order=1):
+    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', search_type='all', brand='all', day=1, appRankShow=1, subclass='all', simple=1, rankEchartType=1, rankType='day', run_time=datetime.date.today(), status=6, keyword_hot_start=4605, typec='day', star='five', delete=-1, orderType='time', commentType='default', genre_type=36, status_type=3, clear_type=1, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc', option=4, app_status_str='all', app_status_sdate='', app_status_edate='', app_status_order='', app_status_sort='', preOrder_order=1, change_inc=0, minResult='', maxResult='', minHints='', maxHints='', minPopular='', maxPopular='', top_history='all', lost_sort='out_time'):
         self.country = country
         self.rank_type = rank_type
         self.version = version
@@ -242,6 +280,15 @@ class Qimai_Diy_Var:
         self.app_status_order = app_status_order
         self.app_status_sort = app_status_sort
         self.preOrder_order = preOrder_order
+        self.change_inc = change_inc
+        self.minResult = minResult
+        self.maxResult = maxResult
+        self.minHints = minHints
+        self.maxHints = maxHints
+        self.minPopular = minPopular
+        self.maxPopular = maxPopular
+        self.lost_sort = lost_sort
+        self.top_history = top_history
 
 # 获取基础信息相关数据；
 class Get_App_Appinfo(Qimai_Diy_Var):
@@ -360,6 +407,11 @@ class Get_Keyword_Info(Qimai_Diy_Var):
         self.results = self.keyword_WordInfo['wordInfo']['search_no']
         return self.results
 
+    def get_keyword_wordID(self):
+        self.get_keyword_wordinfo()
+        self.wordID = self.keyword_WordInfo['wordInfo']['word_id']
+        return self.wordID
+
 # 获取产品的关键词相关数据；
 class Get_App_Keyword(Qimai_Diy_Var):
     def __init__(self, appid):
@@ -613,8 +665,137 @@ class Get_App_Status(Qimai_Diy_Var):
                     return ''
             return ''
 
+# 封装指数排行榜接口；
+class Get_Keyword_HintsRank(Qimai_Diy_Var):
+    def __init__(self):
+        Qimai_Diy_Var.__init__(self)
 
+    def get_hints_rank(self):
+        self.keyword_hintsRank_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/trend/keywordHintsRank?date=%s&page=%s&change_inc=%s&minResult=%s&maxResult=%s&genre=%s&minHints=%s&maxHints=%s&device=%s&country=%s&minPopular=%s&maxPopular=%s' %(self.run_time, page_num, self.change_inc, self.minResult, self.maxResult, self.genre_type, self.minHints, self.maxHints, self.device, self.country, self.minPopular, self.maxPopular)
+            res = session.get(url, headers=headers)
+            self.keyword_hintsRank_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.keyword_hintsRank_list
 
+# 封装关键词落词列表接口；
+class Get_Keyword_LoseNewDownUp_List(Qimai_Diy_Var):
+    def __init__(self, keyword, start_date=datetime.date.today(), end_date=datetime.date.today()):
+        Qimai_Diy_Var.__init__(self)
+        self.keyword = keyword
+        self.start_date = start_date
+        self.end_date = end_date
+
+    def get_lostApp_list(self):
+        self.keyword_lostApp_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=out_time&sort_type=%s&type=out&sdate=%s&edate=%s&page=%s' %(self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
+            res = session.get(url, headers=headers)
+            self.keyword_lostApp_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['total_page']:
+                break
+        return self.keyword_lostApp_list
+
+    def get_newApp_list(self):
+        self.keyword_newApp_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=new_time&sort_type=%s&type=new&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
+            res = session.get(url, headers=headers)
+            self.keyword_newApp_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['total_page']:
+                break
+        return self.keyword_newApp_list
+
+    def get_rankDown_list(self):
+        self.keyword_rankDown_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=down_rank&sort_type=%s&type=down&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
+            res = session.get(url, headers=headers)
+            self.keyword_rankDown_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['total_page']:
+                break
+        return self.keyword_rankDown_list
+
+    def get_rankGoUp_list(self):
+        self.keyword_rankUp_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=up_rank&sort_type=%s&type=up&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
+            res = session.get(url, headers=headers)
+            self.keyword_rankUp_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['total_page']:
+                break
+        return self.keyword_rankUp_list
+
+    def get_t10App_list(self):
+        self.keyword_t10App_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/search/rankHistory?version=%s&device=%s&word=%s&page=%s&country=%s&sdate=%s&edate=%s' % (self.version, self.device, self.keyword, page_num, self.country, self.start_date, self.end_date)
+            res = session.get(url, headers=headers)
+            self.keyword_t10App_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['total_page']:
+                break
+        return self.keyword_t10App_list
+
+# 获取免费、付费、畅销榜单产品列表；
+class Get_FreePaidGross_RankList(Qimai_Diy_Var):
+    def __init__(self, snapshot=''):
+        Qimai_Diy_Var.__init__(self)
+        self.snapshot = snapshot
+
+    def get_updateTime_list(self):
+        url = 'https://api.qimai.cn/rank/indexSnapshot?brand=%s&device=%s&country=%s&genre=%s&date=%s&page=1&is_rank_index=1' %(self.brand, self.device, self.country, self.genre_type, self.run_time)
+        res = session.get(url, headers=headers)
+        self.rank_update_List = res.json()
+
+    def get_freeRank_list(self):
+        self.app_freeRank_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/rank/index?brand=free&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=%s' %(self.device, self.country, self.genre_type, self.run_time, self.snapshot, page_num)
+            res = session.get(url, headers=headers)
+            self.app_freeRank_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.app_freeRank_list
+
+    def get_paidRank_list(self):
+        self.app_paidRank_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/rank/index?brand=paid&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=%s' %(self.device, self.country, self.genre_type, self.run_time, self.snapshot, page_num)
+            res = session.get(url, headers=headers)
+            self.app_paidRank_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.app_paidRank_list
+
+    def get_grossRank_list(self):
+        self.app_grossRank_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/rank/index?brand=grossing&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=%s' %(self.device, self.country, self.genre_type, self.run_time, self.snapshot, page_num)
+            res = session.get(url, headers=headers)
+            self.app_grossRank_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.app_grossRank_list
 
 
 
